"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolanaPlatform = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const chain_1 = require("./chain");
const platformUtils_1 = require("./platformUtils");
const web3_js_1 = require("@solana/web3.js");
// forces SolanaPlatform to implement Platform
var _ = SolanaPlatform;
/**
 * @category Solana
 */
var SolanaPlatform;
(function (SolanaPlatform) {
    SolanaPlatform.platform = 'Solana';
    SolanaPlatform.network = connect_sdk_1.DEFAULT_NETWORK;
    SolanaPlatform.conf = (0, connect_sdk_1.networkPlatformConfigs)(SolanaPlatform.network, SolanaPlatform.platform);
    const registeredProtocols = new Map();
    SolanaPlatform.nativeTokenId = platformUtils_1.SolanaUtils.nativeTokenId, SolanaPlatform.isNativeTokenId = platformUtils_1.SolanaUtils.isNativeTokenId, SolanaPlatform.isSupportedChain = platformUtils_1.SolanaUtils.isSupportedChain, SolanaPlatform.getDecimals = platformUtils_1.SolanaUtils.getDecimals, SolanaPlatform.getBalance = platformUtils_1.SolanaUtils.getBalance, SolanaPlatform.getBalances = platformUtils_1.SolanaUtils.getBalances, SolanaPlatform.sendWait = platformUtils_1.SolanaUtils.sendWait, SolanaPlatform.getCurrentBlock = platformUtils_1.SolanaUtils.getCurrentBlock, SolanaPlatform.chainFromChainId = platformUtils_1.SolanaUtils.chainFromChainId, SolanaPlatform.chainFromRpc = platformUtils_1.SolanaUtils.chainFromRpc;
    function setConfig(_network, _conf) {
        SolanaPlatform.conf = _conf ? _conf : (0, connect_sdk_1.networkPlatformConfigs)(SolanaPlatform.network, SolanaPlatform.platform);
        SolanaPlatform.network = _network;
        return SolanaPlatform;
    }
    SolanaPlatform.setConfig = setConfig;
    function getRpc(chain, commitment = 'confirmed') {
        const rpcAddress = SolanaPlatform.conf[chain].rpc;
        return new web3_js_1.Connection(rpcAddress, commitment);
    }
    SolanaPlatform.getRpc = getRpc;
    function getChain(chain) {
        if (chain in SolanaPlatform.conf)
            return new chain_1.SolanaChain(SolanaPlatform.conf[chain]);
        throw new Error('No configuration available for chain: ' + chain);
    }
    SolanaPlatform.getChain = getChain;
    function getProtocol(protocol) {
        return (0, connect_sdk_1.getProtocolInitializer)(SolanaPlatform.platform, protocol);
    }
    SolanaPlatform.getProtocol = getProtocol;
    async function getWormholeCore(rpc) {
        return getProtocol('WormholeCore').fromRpc(rpc, SolanaPlatform.conf);
    }
    SolanaPlatform.getWormholeCore = getWormholeCore;
    async function getTokenBridge(rpc) {
        return getProtocol('TokenBridge').fromRpc(rpc, SolanaPlatform.conf);
    }
    SolanaPlatform.getTokenBridge = getTokenBridge;
    async function parseTransaction(chain, rpc, tx) {
        const core = await getWormholeCore(rpc);
        return core.parseTransaction(tx);
    }
    SolanaPlatform.parseTransaction = parseTransaction;
})(SolanaPlatform || (exports.SolanaPlatform = SolanaPlatform = {}));
//# sourceMappingURL=platform.js.map